
PALETTE_URL_PARAM = "?palette="
BLACK_HEX = 000
WHITE_HEX = fff
JSON_STRING = 'json'
CSS_STRINGS = ['.image-fg-ex-1', '.image-bg-ex-2', '.image-bg-vibrant', '.image-fg-muted-dark', 
				'.image-bg-muted', '.image-fg-vibrant-light', '.image-bg-muted-light', '.image-fg-vibrant-dark']

__all__ = [ 'PALETTE_URL_PARAM', 'BLACK_HEX', 'WHITE_HEX', 'JSON_STRING', 'CSS_STRINGS' ]