BLACK_HEX = '000'
WHITE_HEX = 'fff'
IMG_BLUEHAT = "https://assets.imgix.net/examples/bluehat.jpg"
IMG_PINE = "https://sherwinski.imgix.net/pineneedles.jpg"
BROKEN_URL = "https://assets.imgix.net/examples/invalid"
INVALID_URL = "https://google.com"

CSS_BLUEHAT = """.image-fg-1 { color:#0d0c10 !important; } .image-bg-1 { background-color:#0d0c10 !important; } .image-fg-2 { color:#015091 !important; } .image-bg-2 { background-color:#015091 !important; } .image-fg-3 { color:#0870d3 !important; } .image-bg-3 { background-color:#0870d3 !important; } .image-fg-4 { color:#239be0 !important; } .image-bg-4 { background-color:#239be0 !important; } .image-fg-5 { color:#b1dfeb !important; } .image-bg-5 { background-color:#b1dfeb !important; } .image-fg-6 { color:#f0c9b4 !important; } .image-bg-6 { background-color:#f0c9b4 !important; } .image-fg-ex-1 { color:#000000 !important; } .image-bg-ex-1 { background-color:#000000 !important; } .image-fg-ex-2 { color:#ffffff !important; } .image-bg-ex-2 { background-color:#ffffff !important; } .image-fg-vibrant { color:#0d95e4 !important; } .image-bg-vibrant { background-color:#0d95e4 !important; } .image-fg-muted-dark { color:#38445c !important; } .image-bg-muted-dark { background-color:#38445c !important; } .image-fg-muted { color:#966760 !important; } .image-bg-muted { background-color:#966760 !important; } .image-fg-vibrant-light { color:#72c5f4 !important; } .image-bg-vibrant-light { background-color:#72c5f4 !important; } .image-fg-muted-light { color:#d8b6aa !important; } .image-bg-muted-light { background-color:#d8b6aa !important; } .image-fg-vibrant-dark { color:#015091 !important; } .image-bg-vibrant-dark { background-color:#015091 !important; }"""

JSON_BLUEHAT = {'colors': [{'red': 0.0509804, 'hex': '#0d0c10', 'blue': 0.0627451, 'green': 0.0470588}, {'red': 0.00392157, 'hex': '#015091', 'blue': 0.568627, 'green': 0.313725}, {'red': 0.0313725, 'hex': '#0870d3', 'blue': 0.827451, 'green': 0.439216}, {'red': 0.137255, 'hex': '#239be0', 'blue': 0.878431, 'green': 0.607843}, {'red': 0.694118, 'hex': '#b1dfeb', 'blue': 0.921569, 'green': 0.87451}, {'red': 0.941176, 'hex': '#f0c9b4', 'blue': 0.705882, 'green': 0.788235}], 'average_luminance': 0.708396, 'dominant_colors': {'vibrant': {'red': 0.0509804, 'hex': '#0d95e4', 'blue': 0.894118, 'green': 0.584314}, 'muted_light': {'red': 0.847059, 'hex': '#d8b6aa', 'blue': 0.666667, 'green': 0.713725}, 'muted': {'red': 0.588235, 'hex': '#966760', 'blue': 0.376471, 'green': 0.403922}, 'vibrant_dark': {'red': 0.00392157, 'hex': '#015091', 'blue': 0.568627, 'green': 0.313725}, 'vibrant_light': {'red': 0.447059, 'hex': '#72c5f4', 'blue': 0.956863, 'green': 0.772549}, 'muted_dark': {'red': 0.219608, 'hex': '#38445c', 'blue': 0.360784, 'green': 0.266667}}}

CSS_PINE = """.image-fg-1 { color:#f6e4ee !important; } .image-bg-1 { background-color:#f6e4ee !important; } .image-fg-2 { color:#d9afc3 !important; } .image-bg-2 { background-color:#d9afc3 !important; } .image-fg-3 { color:#aac373 !important; } .image-bg-3 { background-color:#aac373 !important; } .image-fg-4 { color:#6e9170 !important; } .image-bg-4 { background-color:#6e9170 !important; } .image-fg-5 { color:#375d2d !important; } .image-bg-5 { background-color:#375d2d !important; } .image-fg-6 { color:#2c4309 !important; } .image-bg-6 { background-color:#2c4309 !important; } .image-fg-ex-1 { color:#ffffff !important; } .image-bg-ex-1 { background-color:#ffffff !important; } .image-fg-ex-2 { color:#000000 !important; } .image-bg-ex-2 { background-color:#000000 !important; } .image-fg-vibrant { color:#aac373 !important; } .image-bg-vibrant { background-color:#aac373 !important; } .image-fg-muted-dark { color:#36522c !important; } .image-bg-muted-dark { background-color:#36522c !important; } .image-fg-muted { color:#98656d !important; } .image-bg-muted { background-color:#98656d !important; } .image-fg-vibrant-light { color:#e1acba !important; } .image-bg-vibrant-light { background-color:#e1acba !important; } .image-fg-muted-light { color:#d3abb5 !important; } .image-bg-muted-light { background-color:#d3abb5 !important; } .image-fg-vibrant-dark { color:#2c4309 !important; } .image-bg-vibrant-dark { background-color:#2c4309 !important; }"""

JSON_PINE = {'colors': [{'red': 0.964706, 'hex': '#f6e4ee', 'blue': 0.933333, 'green': 0.894118}, {'red': 0.85098, 'hex': '#d9afc3', 'blue': 0.764706, 'green': 0.686275}, {'red': 0.666667, 'hex': '#aac373', 'blue': 0.45098, 'green': 0.764706}, {'red': 0.431373, 'hex': '#6e9170', 'blue': 0.439216, 'green': 0.568627}, {'red': 0.215686, 'hex': '#375d2d', 'blue': 0.176471, 'green': 0.364706}, {'red': 0.172549, 'hex': '#2c4309', 'blue': 0.0352941, 'green': 0.262745}], 'average_luminance': 0.38134, 'dominant_colors': {'vibrant': {'red': 0.666667, 'hex': '#aac373', 'blue': 0.45098, 'green': 0.764706}, 'muted_light': {'red': 0.827451, 'hex': '#d3abb5', 'blue': 0.709804, 'green': 0.670588}, 'muted': {'red': 0.596078, 'hex': '#98656d', 'blue': 0.427451, 'green': 0.396078}, 'vibrant_dark': {'red': 0.172549, 'hex': '#2c4309', 'blue': 0.0352941, 'green': 0.262745}, 'vibrant_light': {'red': 0.882353, 'hex': '#e1acba', 'blue': 0.729412, 'green': 0.67451}, 'muted_dark': {'red': 0.211765, 'hex': '#36522c', 'blue': 0.172549, 'green': 0.321569}}}